@@ -1,7 +1,7 @@
 package Complete::Bash;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $DATE = '2015-03-04'; # DATE
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -396,7 +396,7 @@ POD. Aside from `words`, this function also recognizes these keys:
   doing completion inside `Term::ReadLine`, for example, where the library
   expects an array.
 
-* `escmode` (str): Escaping mode for entries. Either `default` (most
+* `esc_mode` (str): Escaping mode for entries. Either `default` (most
   nonalphanumeric characters will be escaped), `shellvar` (like `default`, but
   dollar sign `$` will not be escaped, convenient when completing environment
   variables for example), `filename` (currently equals to `default`), `option`
@@ -461,7 +461,8 @@ sub format_completion {
     $hcomp = {words=>$hcomp} unless ref($hcomp) eq 'HASH';
     my $comp     = $hcomp->{words};
     my $as       = $hcomp->{as} // 'string';
-    my $escmode  = $hcomp->{escmode} // 'default';
+    # 'escmode' key is deprecated (Complete 0.11-) and will be removed later
+    my $esc_mode = $hcomp->{esc_mode} // $hcomp->{escmode} // 'default';
     my $path_sep = $hcomp->{path_sep};
 
     if (defined($path_sep) && @$comp == 1) {
@@ -506,10 +507,10 @@ sub format_completion {
     my @res;
     for my $entry (@$comp) {
         my $word = ref($entry) eq 'HASH' ? $entry->{word} : $entry;
-        if ($escmode eq 'shellvar') {
+        if ($esc_mode eq 'shellvar') {
             # don't escape $
             $word =~ s!([^A-Za-z0-9,+._/\$~-])!\\$1!g;
-        } elsif ($escmode eq 'none') {
+        } elsif ($esc_mode eq 'none') {
             # no escaping
         } else {
             # default
@@ -540,7 +541,7 @@ Complete::Bash - Completion module for bash shell
 
 =head1 VERSION
 
-This document describes version 0.16 of Complete::Bash (from Perl distribution Complete-Bash), released on 2015-01-03.
+This document describes version 0.17 of Complete::Bash (from Perl distribution Complete-Bash), released on 2015-03-04.
 
 =head1 DESCRIPTION
 
@@ -609,7 +610,7 @@ instead of the lines joined together). Returning array is useful if you are
 doing completion inside C<Term::ReadLine>, for example, where the library
 expects an array.
 
-=item * C<escmode> (str): Escaping mode for entries. Either C<default> (most
+=item * C<esc_mode> (str): Escaping mode for entries. Either C<default> (most
 nonalphanumeric characters will be escaped), C<shellvar> (like C<default>, but
 dollar sign C<$> will not be escaped, convenient when completing environment
 variables for example), C<filename> (currently equals to C<default>), C<option>
@@ -659,6 +660,7 @@ Either an array or hash. See function description for more details.
 
 Return value: Formatted string (or array, if `as` is set to `array`) (str|array)
 
+
 =head2 parse_cmdline($cmdline, $point, $word_breaks, $preserve_quotes) -> array
 
 Parse shell command-line for processing by completion routines.
@@ -715,6 +717,7 @@ Note that the characters won't break words if inside quotes or escaped.
 
 Return value:  (array)
 
+
 Return a 2-element array: C<[$words, $cword]>. C<$words> is array of str,
 equivalent to C<COMP_WORDS> provided by bash to shell functions. C<$cword> is an
 integer, equivalent to C<COMP_CWORD> provided by bash to shell functions. The
@@ -805,24 +808,27 @@ element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
 Return value:  (hash)
+
 =head1 SEE ALSO
 
+
+L<Complete>
+
+=head1 SEE ALSO (2)
+
 Other modules related to bash shell tab completion: L<Bash::Completion>,
 L<Getopt::Complete>. L<Term::Bash::Completion::Generator>
 
 Programmable Completion section in Bash manual:
 L<https://www.gnu.org/software/bash/manual/html_node/Programmable-Completion.html>
 
-
-L<Complete>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Complete-Bash>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-Complete-Bash>.
+Source repository is at L<https://github.com/perlancar/perl-Complete-Bash>.
 
 =head1 BUGS
 
